@@ -39,6 +39,8 @@ class IBApi(EWrapper, EClient):
             self.event_thread[Events.HISTORICAL_DATA].set()
         if self.global_state.service == Events.SCANNER_DATA.value:
             self.event_thread[Events.CANCEL_DATA].set()
+        if self.global_state.service == Events.TIMESTAMP_DATA.value:
+            self.event_thread[Events.TIMESTAMP_DATA].set()
 
     def nextValidId(self, orderId):
         super().nextValidId(orderId)
@@ -81,3 +83,7 @@ class IBApi(EWrapper, EClient):
     def openOrder(self, orderId: int, contract: Contract, order: Order, orderState: OrderState):
         if self.ib_handlers.open_order:
             self.ib_handlers.open_order(orderId, contract, order, orderState)
+    
+    def headTimestamp(self, reqId:int, headTimestamp:str):
+        self.global_state.set_time_stamp(headTimestamp)
+        self.event_thread[Events.TIMESTAMP_DATA].set()
